@@ -2,13 +2,16 @@
 
 ##' @title segment MSA
 ##' @param field a numeric vector of the field size.
+##' @return ggplot layers
 ##' @examples
 ##' library(ggplot2)
 ##' f <- system.file("extdata/sample.fasta", package="ggmsa")
 ##' # 2 fields
-##' ggmsa(f, end = 120, font = NULL, color="Chemistry_AA") + facet_msa(field = 60)
+##' ggmsa(f, end = 120, font = NULL, color="Chemistry_AA") + 
+##'   facet_msa(field = 60)
 ##' # 3 fields
-##' ggmsa(f, end = 120, font = NULL,  color="Chemistry_AA") + facet_msa(field = 40)
+##' ggmsa(f, end = 120, font = NULL,  color="Chemistry_AA") + 
+##'   facet_msa(field = 40)
 ##' @export
 ##' @author Lang Zhou
 facet_msa <- function(field) {
@@ -28,14 +31,11 @@ facet_data <- function(msaData, field) {
     msaData$facet <- pos_reset %/% field
 
 
-    msaData[(pos_reset %% field) == 0, "facet"] <- msaData[(pos_reset %% field) == 0, "facet"] - 1
+    msaData[(pos_reset %% field) == 0, "facet"] <- 
+        msaData[(pos_reset %% field) == 0, "facet"] - 1
 
-    # if ('x' %in% colnames(msaData))
-    #     msaData$x <- msaData$x - (msaData$facet * field) #ly_label translation
-    #
-    # msaData$position <- msaData$position - (msaData$facet * field) #ly_bg translation
     return(msaData)
-    #msa_facet <- facet_wrap(msaData$facet, nrow = num_facet)
+
 }
 
 
